@@ -5,7 +5,12 @@ from pathlib import Path
 
 from patchwork.common.context_strategy.context_strategies import ContextStrategies
 from patchwork.common.context_strategy.position import Position
-from patchwork.common.ignore import is_ignored
+from patchwork.common.utils.filter_paths import (
+    IGNORE_DIRS,
+    IGNORE_EXTS_GLOBS,
+    IGNORE_FILES_GLOBS,
+    PathFilter,
+)
 from patchwork.common.utils.utils import open_with_chardet
 from patchwork.logger import logger
 from patchwork.step import Step
@@ -67,8 +72,7 @@ class ExtractCodeContexts(Step):
     required_keys = {}
 
     def __init__(self, inputs: dict):
-        logger.info(f"Run started {self.__class__.__name__}")
-
+        super().__init__(inputs)
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
@@ -90,26 +94,34 @@ class ExtractCodeContexts(Step):
             )
             extracted_code_contexts.append(extracted_code_context)
 
-        logger.info(f"Run completed {self.__class__.__name__}")
-
         return dict(
             files_to_patch=extracted_code_contexts,
         )
 
-    def get_positions(self, max_depth):
+    def get_positions(self, max_depth: int):
+        ignored_groks = IGNORE_DIRS | IGNORE_EXTS_GLOBS | IGNORE_FILES_GLOBS
+        path_filter = PathFilter(base_path=self.base_path, ignored_groks=ignored_groks, max_depth=max_depth)
+
         files_to_consider = []
         if self.base_path.is_file():
             files_to_consider.append(self.base_path)
         else:
             for root, dirs, files in os.walk(self.base_path):
-                current_depth = len(Path(root).relative_to(self.base_path).parts)
-                if max_depth != -1 and current_depth > max_depth:
+                possible_depth = path_filter.get_depth_ignored(root)
+                if possible_depth is not None:
                     dirs[:] = []  # Prune subdirectories
                     continue
+
                 for file in files:
                     file_path = Path(root) / file
-                    if not file_path.is_file() or is_ignored(file_path):
+                    if not file_path.is_file():
                         continue
+
+                    possible_grok = path_filter.get_grok_ignored(file_path)
+                    if possible_grok is not None:
+                        logger.warning(f'Ignoring file: {file_path} because of "{possible_grok}" exclusion filter')
+                        continue
+
                     files_to_consider.append(file_path)
 
         grouping = getattr(ContextStrategies, self.context_grouping, ContextStrategies.ALL)
