@@ -33,13 +33,13 @@ def handle_indent(src: list[str], target: list[str], start: int, end: int) -> li
 
 
 def replace_code_in_file(
-        file_path: str,
-        start_line: int | None,
-        end_line: int | None,
-        new_code: str,
+    file_path: str,
+    start_line: int | None,
+    end_line: int | None,
+    new_code: str,
 ) -> None:
     path = Path(file_path)
-    if path.exists():
+    if path.exists() and start_line is not None and end_line is not None:
         """Replaces specified lines in a file with new code."""
         text = path.read_text()
 
@@ -70,7 +70,7 @@ class ModifyCode(Step):
     def run(self) -> dict:
         modified_code_files = []
         sorted_list = sorted(
-            zip(self.files_to_patch, self.extracted_responses), key=lambda x: x[0]["startLine"], reverse=True
+            zip(self.files_to_patch, self.extracted_responses), key=lambda x: x[0].get("startLine", -1), reverse=True
         )
         if len(sorted_list) == 0:
             self.set_status(StepStatus.SKIPPED, "No code snippets to modify.")
